@@ -107,7 +107,11 @@ def print_model_field_values(
             rprint(
                 f"[italic grey50]{escape(model_fields[k].field_info.description)}[/]"
             )
-        rprint("[green]" + escape(repr(v)) + "[/]")
+        rprint(
+            "[green]"
+            + escape(str(v) if isinstance(v, (bytes, str)) else repr(v))
+            + "[/]"
+        )
 
 
 def print_command_inputs(command: "PipelimeCommand"):  # type: ignore # noqa: E602,F821
